@@ -31,16 +31,14 @@ class HtmlParser(HTMLParser):
     def handle_starttag(self, tag, attrs):
         if tag == 'body':
             self.body = True
-        if tag == 'p':
-            self.get_data = True
+        if tag == 'footer':
+            self.body = False
         if tag == 'script' or tag == 'a':
             self.get_data = False
 
     def handle_endtag(self, tag):
         if tag == 'body':
             self.body = False
-        if tag == 'p':
-            self.get_data = False
         if tag == 'script' or tag == 'a':
             self.get_data = True
 
@@ -65,4 +63,4 @@ class DocParser(object):
             return
         body = ET.fromstring(zfile.read(docid))
         text = '\n'.join([et.text.strip() for et in body.iter() if et.text])
-        return text.encode('utf-8')
+        return text
